==> elgg-1.10.1.zip: elgg-1.10.1/mod/reportedcontent/languages/da.php <==
<?php
return array(

	'item:object:reported_content' => 'Rapporterede poster',
	'admin:administer_utilities:reportedcontent' => 'Rapporteret indhold',
	'reportedcontent' => 'Rapporteret indhold',
	'reportedcontent:this' => 'Rapporter dette',
	'reportedcontent:this:tooltip' => 'Rapporter denne side til en administrator',
	'reportedcontent:none' => 'Der er ikke noget rapporteret indhold',
	'reportedcontent:report' => 'Rapporter til administrationen',
	'reportedcontent:deleted' => 'Det rapporterede indhold er blevet slettet',
	'reportedcontent:notdeleted' => 'Vi kunne ikke slette denne rapport',
	'reportedcontent:delete' => 'Slet den',
	'reportedcontent:areyousure' => 'Er du sikker på at du vil slette?',
	'reportedcontent:archive' => 'Arkiver den',
	'reportedcontent:archived' => 'Rapporten er blevet arkiveret',
	'reportedcontent:visit' => 'Se rapporteret post',
	'reportedcontent:by' => 'Rapport af',
	'reportedcontent:objecttitle' => 'Side titel',
	'reportedcontent:objecturl' => 'Side Url',
	'reportedcontent:reason' => 'Begrundelse for rapport',
	'reportedcontent:description' => 'Hvorfor rapporterer du dette?',
	'reportedcontent:address' => 'Placering af emnet',
	'reportedcontent:success' => 'Din rapport er blevet sendt til administrationen',
	'reportedcontent:failing' => 'Din rapport kunne ikke sendes',
	'reportedcontent:report' => 'Rapporter til administrationen',
	'reportedcontent:instructions' => 'Denne rapport vil blive sendt til administratorer af dette websted til gennemsyn.',
	'reportedcontent:numbertodisplay' => 'Antal rapporter, der skal vises',
	'reportedcontent:widget:description' => 'Vis rapporteret indhold',
	'reportedcontent:user' => 'Rapporter bruger',

	'reportedcontent:failed' => 'Beklager, forsøget på at rapportere dette indhold fejlede.',
	'reportedcontent:notarchived' => 'Vi kunne ikke arkivere denne rapport',
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/reportedcontent/languages/da.php <==
<?php
return array(

	'item:object:reported_content' => 'Rapporterede poster',
	'admin:administer_utilities:reportedcontent' => 'Rapporteret indhold',
	'reportedcontent' => 'Rapporteret indhold',
	'reportedcontent:this' => 'Rapporter dette',
	'reportedcontent:this:tooltip' => 'Rapporter denne side til en administrator',
	'reportedcontent:none' => 'Der er ikke noget rapporteret indhold',
	'reportedcontent:report' => 'Rapporter til administrationen',
	'reportedcontent:deleted' => 'Det rapporterede indhold er blevet slettet',
	'reportedcontent:notdeleted' => 'Vi kunne ikke slette denne rapport',
	'reportedcontent:delete' => 'Slet den',
	'reportedcontent:archive' => 'Arkiver den',
	'reportedcontent:archived' => 'Rapporten er blevet arkiveret',
	'reportedcontent:by' => 'Rapport af',
	'reportedcontent:objecttitle' => 'Side titel',
	'reportedcontent:objecturl' => 'Side Url',
	'reportedcontent:reason' => 'Begrundelse for rapport',
	'reportedcontent:description' => 'Hvorfor rapporterer du dette?',
	'reportedcontent:address' => 'Placering af emnet',
	'reportedcontent:success' => 'Din rapport er blevet sendt til administrationen',
	'reportedcontent:refresh' => 'Refresh this listing',
	'reportedcontent:report' => 'Rapporter til administrationen',
	'reportedcontent:instructions' => 'Denne rapport vil blive sendt til administratorer af dette websted til gennemsyn.',
	'reportedcontent:numbertodisplay' => 'Antal rapporter, der skal vises',
	'reportedcontent:user' => 'Rapporter bruger',

	'reportedcontent:failed' => 'Beklager, forsøget på at rapportere dette indhold fejlede.',
	'reportedcontent:notarchived' => 'Vi kunne ikke arkivere denne rapport',
	
	'widgets:reportedcontent:name' => 'Reported content',
	'widgets:reportedcontent:description' => 'Display reported content',
);
